summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorSimon Glass <sjg@chromium.org>2011-08-22 08:03:31 -0600
committerSimon Glass <sjg@chromium.org>2011-09-13 15:33:37 -0700
commit903aded18bcb7d8d32f0ec9a68ea2a257f567c2b (patch)
treed1fe6d6f8fc648ee629b72d26d3f6dfd67e7d973 /include
parent36f402167d2fdfd2b20756428bbdaa9559878cde (diff)
fdt: Correct debug message compiler error
This corrects a compile erron when DEBUG is defined in fdt_decode. Also change property to prop_name throughout, for consistency. BUG=chromium-os:19353 TEST=build for Seaboard Change-Id: I7503343cea20b556afeb0e507ce9d2cf2165c837 Reviewed-on: http://gerrit.chromium.org/gerrit/7639 Reviewed-by: Stefan Reinauer <reinauer@google.com> Tested-by: Simon Glass <sjg@chromium.org>
Diffstat (limited to 'include')
-rw-r--r--include/fdt_decode.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/fdt_decode.h b/include/fdt_decode.h
index 02c452e767d..5111d3e5152 100644
--- a/include/fdt_decode.h
+++ b/include/fdt_decode.h
@@ -361,11 +361,11 @@ int fdt_decode_get_spi_switch(const void *blob, struct fdt_spi_uart *config);
*
* @param blob FDT blob to use
* @param node Node to look at
* @param property Node property name
* @param gpio gpio elements to fill from FDT
* @return 0 if ok, -FDT_ERR_MISSING if the property is missing.
*/
-int fdt_decode_gpio(const void *blob, int node, const char *property,
+int fdt_decode_gpio(const void *blob, int node, const char *prop_name,
struct fdt_gpio_state *gpio);
/**
@@ -374,14 +374,14 @@ int fdt_decode_gpio(const void *blob, int node, const char *property,
*
* @param blob FDT blob to use
* @param node Node to look at
* @param property Node property name
* @param gpio Array of gpio elements to fill from FDT. This will be
* untouched if either 0 or an error is returned
* @param max_count Maximum number of elements allowed
* @return number of GPIOs read if ok, -FDT_ERR_BADLAYOUT if max_count would
* be exceeded, or -FDT_ERR_MISSING if the property is missing.
*/
-int fdt_decode_gpios(const void *blob, int node, const char *property,
+int fdt_decode_gpios(const void *blob, int node, const char *prop_name,
struct fdt_gpio_state *gpio, int max_count);
/**
@@ -361,11 +361,11 @@ int fdt_decode_get_spi_switch(const void *blob, struct fdt_spi_uart *config);
* @param blob FDT blob to use
* @param node Node to look at
- * @param property Node property name
+ * @param prop_name Node property name
* @param gpio gpio elements to fill from FDT
* @return 0 if ok, -FDT_ERR_MISSING if the property is missing.
@@ -374,14 +374,14 @@ int fdt_decode_gpio(const void *blob, int node, const char *property,
* @param blob FDT blob to use
* @param node Node to look at
- * @param property Node property name
+ * @param prop_name Node property name
* @param gpio Array of gpio elements to fill from FDT. This will be
* untouched if either 0 or an error is returned